<?php
  /**
   * Example of php client for humidity graph for one plant with jpgraph
   *
   * @author Emilie Gennari, Anne Tireau
   * @created octobre 2010
   * @editor INRA-MISTEA
   * @contact anne.tireau@supagro.inra.fr, vincent.negre@supagro.inra.fr
   */

	// Declaration de la bibliotheque JPgraph (trace de courbes)

	include("../../../lib/jpgraph-2.1.3/jpgraph.php");
	include("../../../lib/jpgraph-2.1.3/jpgraph_line.php");
	
        include_once("FunctionsWS.php");
	
	$fonctions=new FunctionsWS();


	$resultsHumidityXML=$fonctions->callGetObservedHumidity("An-1","C1M7");
	$id = 0; // the first repetition of the case of the experiment

	/* tableau dates */
	$tabDate=array();
	$i=0;
	foreach($resultsHumidityXML->measures[$id]->measure as $measure){
	  $tabDate[$i]=$measure->date;	
	  $i++;
	}

	/*tableau valeurs*/
	$tabValeurs=array();
	$j=0;
	foreach($resultsHumidityXML->measures[$id]->measure as $measure){
	  $tabValeurs[$j]=(float)$measure->value;
	  $j++;
	}
	$dataX=transformeDate($tabDate);
	
	// Initialisation du graphique
	$graph = new Graph(800,500,"auto");
	
	// Marges autour du graphique
	$graph->img->SetMargin(80,150,40,100);

	// Choix du type d'echelle
	$graph->SetScale("linlin",min($tabValeurs),max($tabValeurs),min($dataX),max($dataX));
	
	// Titre du graphique
	$graph->title->Set($resultsHumidityXML->measures[$id]->measure[0]->variable. " of ".$resultsHumidityXML->measures[$id]->genotype." and ".$resultsHumidityXML->measures[$id]->experiment );

	// Ajustement de legende
	$graph->legend->Pos(0.3,0.5,"right","top");	

	// Legende de l'axe des x
	$graph->xaxis->SetLabelAngle(90);
	$graph->xaxis->SetTitle("Date [hours]",'middle');
	$graph->xaxis->SetTitlemargin(35);	

        // Legende de l'axe des y
        //$graph->yaxis->SetLabelAngle(90);
        $graph->yaxis->SetTitle($resultsHumidityXML->measures[$id]->measure[0]->variable." [".$resultsHumidityXML->measures[$id]->measure[0]->unit."]",'middle');
	$graph->yaxis->SetTitlemargin(45);

	// Contruction de la courbe

	// On cree la courbe avec le tableau des valeurs
	$p1 = new LinePlot($tabValeurs,$dataX);	
	// Affichage de points a chaque valeur
	$p1->mark->SetType(MARK_FILLEDCIRCLE);
	// Couleur des points
	$p1->mark->SetFillColor("red");
	// Taille des points
	$p1->mark->SetWidth(1);
	// Couleur de la courbe
	$p1->SetColor("red");
	
	// Ajout de la courbe au graphique	
	$graph->Add($p1);

	// Create graphic 	
	$graph->Stroke('graphique.jpg');
	echo "<center><img src='graphique.jpg'/></center>";



	// Fonction qui transforme le tableau de dates en tableau d'entiers
	// (nombre des heures) pour pouvoir avoir des intervalles de temps
	//  justes sur l'axe des abscisses
	function transformeDate($datax) {
  		$dateHeurePlusAncienne=explode(' ',$datax[0]);
	  	$datePlusAncienne=explode('-',$dateHeurePlusAncienne[0]);
		$heurePlusAncienne=explode(':',$dateHeurePlusAncienne[1]);

		$timetampDateHeurePlusAncienne=mktime($heurePlusAncienne[0],$heurePlusAncienne[1],$heurePlusAncienne[2],$datePlusAncienne[1],$datePlusAncienne[2],$datePlusAncienne[0]);

		for($i=0;$i<count($datax);$i++){

		    $dateHeureCourante=explode(' ',$datax[$i]);
		    $dateCourante=explode('-',$dateHeureCourante[0]);
		    $heureCourante=explode(':',$dateHeureCourante[1]);

		    $timetampDateHeureCourante=mktime($heureCourante[0],$heureCourante[1],$heureCourante[2],$dateCourante[1],$dateCourante[2],$dateCourante[0]);

		    $dataX[$i]=($timetampDateHeureCourante-$timetampDateHeurePlusAncienne)/3600;
		}
		return $dataX;
	}
?>
